# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['IndexArgs', 'Index']

@pulumi.input_type
class IndexArgs:
    def __init__(__self__, *,
                 keys: pulumi.Input[Sequence[pulumi.Input['IndexKeyArgs']]],
                 table_name_or_id: pulumi.Input[str],
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 is_if_not_exists: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Index resource.
        :param pulumi.Input[Sequence[pulumi.Input['IndexKeyArgs']]] keys: A set of keys for a secondary index.
        :param pulumi.Input[str] table_name_or_id: A table name within the compartment, or a table OCID.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] compartment_id: The OCID of the table's compartment.  Required if the tableNameOrId path parameter is a table name. Optional if tableNameOrId is an OCID.  If tableNameOrId is an OCID, and compartmentId is supplied, the latter must match the identified table's compartmentId.
        :param pulumi.Input[bool] is_if_not_exists: If true, the operation completes successfully even when the index exists.  Otherwise, an attempt to create an index that already exists will return an error.
        :param pulumi.Input[str] name: Index name.
        """
        pulumi.set(__self__, "keys", keys)
        pulumi.set(__self__, "table_name_or_id", table_name_or_id)
        if compartment_id is not None:
            pulumi.set(__self__, "compartment_id", compartment_id)
        if is_if_not_exists is not None:
            pulumi.set(__self__, "is_if_not_exists", is_if_not_exists)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def keys(self) -> pulumi.Input[Sequence[pulumi.Input['IndexKeyArgs']]]:
        """
        A set of keys for a secondary index.
        """
        return pulumi.get(self, "keys")

    @keys.setter
    def keys(self, value: pulumi.Input[Sequence[pulumi.Input['IndexKeyArgs']]]):
        pulumi.set(self, "keys", value)

    @property
    @pulumi.getter(name="tableNameOrId")
    def table_name_or_id(self) -> pulumi.Input[str]:
        """
        A table name within the compartment, or a table OCID.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "table_name_or_id")

    @table_name_or_id.setter
    def table_name_or_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "table_name_or_id", value)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[pulumi.Input[str]]:
        """
        The OCID of the table's compartment.  Required if the tableNameOrId path parameter is a table name. Optional if tableNameOrId is an OCID.  If tableNameOrId is an OCID, and compartmentId is supplied, the latter must match the identified table's compartmentId.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="isIfNotExists")
    def is_if_not_exists(self) -> Optional[pulumi.Input[bool]]:
        """
        If true, the operation completes successfully even when the index exists.  Otherwise, an attempt to create an index that already exists will return an error.
        """
        return pulumi.get(self, "is_if_not_exists")

    @is_if_not_exists.setter
    def is_if_not_exists(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_if_not_exists", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Index name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _IndexState:
    def __init__(__self__, *,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 is_if_not_exists: Optional[pulumi.Input[bool]] = None,
                 keys: Optional[pulumi.Input[Sequence[pulumi.Input['IndexKeyArgs']]]] = None,
                 lifecycle_details: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 table_id: Optional[pulumi.Input[str]] = None,
                 table_name: Optional[pulumi.Input[str]] = None,
                 table_name_or_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Index resources.
        :param pulumi.Input[str] compartment_id: The OCID of the table's compartment.  Required if the tableNameOrId path parameter is a table name. Optional if tableNameOrId is an OCID.  If tableNameOrId is an OCID, and compartmentId is supplied, the latter must match the identified table's compartmentId.
        :param pulumi.Input[bool] is_if_not_exists: If true, the operation completes successfully even when the index exists.  Otherwise, an attempt to create an index that already exists will return an error.
        :param pulumi.Input[Sequence[pulumi.Input['IndexKeyArgs']]] keys: A set of keys for a secondary index.
        :param pulumi.Input[str] lifecycle_details: A message describing the current state in more detail.
        :param pulumi.Input[str] name: Index name.
        :param pulumi.Input[str] state: The state of an index.
        :param pulumi.Input[str] table_id: the OCID of the table to which this index belongs.
        :param pulumi.Input[str] table_name: The name of the table to which this index belongs.
        :param pulumi.Input[str] table_name_or_id: A table name within the compartment, or a table OCID.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        if compartment_id is not None:
            pulumi.set(__self__, "compartment_id", compartment_id)
        if is_if_not_exists is not None:
            pulumi.set(__self__, "is_if_not_exists", is_if_not_exists)
        if keys is not None:
            pulumi.set(__self__, "keys", keys)
        if lifecycle_details is not None:
            pulumi.set(__self__, "lifecycle_details", lifecycle_details)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if table_id is not None:
            pulumi.set(__self__, "table_id", table_id)
        if table_name is not None:
            pulumi.set(__self__, "table_name", table_name)
        if table_name_or_id is not None:
            pulumi.set(__self__, "table_name_or_id", table_name_or_id)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[pulumi.Input[str]]:
        """
        The OCID of the table's compartment.  Required if the tableNameOrId path parameter is a table name. Optional if tableNameOrId is an OCID.  If tableNameOrId is an OCID, and compartmentId is supplied, the latter must match the identified table's compartmentId.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="isIfNotExists")
    def is_if_not_exists(self) -> Optional[pulumi.Input[bool]]:
        """
        If true, the operation completes successfully even when the index exists.  Otherwise, an attempt to create an index that already exists will return an error.
        """
        return pulumi.get(self, "is_if_not_exists")

    @is_if_not_exists.setter
    def is_if_not_exists(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_if_not_exists", value)

    @property
    @pulumi.getter
    def keys(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['IndexKeyArgs']]]]:
        """
        A set of keys for a secondary index.
        """
        return pulumi.get(self, "keys")

    @keys.setter
    def keys(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['IndexKeyArgs']]]]):
        pulumi.set(self, "keys", value)

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> Optional[pulumi.Input[str]]:
        """
        A message describing the current state in more detail.
        """
        return pulumi.get(self, "lifecycle_details")

    @lifecycle_details.setter
    def lifecycle_details(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lifecycle_details", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Index name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        The state of an index.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="tableId")
    def table_id(self) -> Optional[pulumi.Input[str]]:
        """
        the OCID of the table to which this index belongs.
        """
        return pulumi.get(self, "table_id")

    @table_id.setter
    def table_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "table_id", value)

    @property
    @pulumi.getter(name="tableName")
    def table_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the table to which this index belongs.
        """
        return pulumi.get(self, "table_name")

    @table_name.setter
    def table_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "table_name", value)

    @property
    @pulumi.getter(name="tableNameOrId")
    def table_name_or_id(self) -> Optional[pulumi.Input[str]]:
        """
        A table name within the compartment, or a table OCID.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "table_name_or_id")

    @table_name_or_id.setter
    def table_name_or_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "table_name_or_id", value)


class Index(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 is_if_not_exists: Optional[pulumi.Input[bool]] = None,
                 keys: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['IndexKeyArgs']]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 table_name_or_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource provides the Index resource in Oracle Cloud Infrastructure NoSQL Database service.

        Create a new index on the table identified by tableNameOrId.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_index = oci.nosql.Index("testIndex",
            keys=[oci.nosql.IndexKeyArgs(
                column_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                json_field_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                json_path=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            )],
            table_name_or_id=oci_nosql_table_name_or["test_table_name_or"]["id"],
            compartment_id=var["compartment_id"],
            is_if_not_exists=var["index_is_if_not_exists"])
        ```

        ## Import

        Indexes can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Nosql/index:Index test_index "tables/{tableNameOrId}/indexes/{indexName}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] compartment_id: The OCID of the table's compartment.  Required if the tableNameOrId path parameter is a table name. Optional if tableNameOrId is an OCID.  If tableNameOrId is an OCID, and compartmentId is supplied, the latter must match the identified table's compartmentId.
        :param pulumi.Input[bool] is_if_not_exists: If true, the operation completes successfully even when the index exists.  Otherwise, an attempt to create an index that already exists will return an error.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['IndexKeyArgs']]]] keys: A set of keys for a secondary index.
        :param pulumi.Input[str] name: Index name.
        :param pulumi.Input[str] table_name_or_id: A table name within the compartment, or a table OCID.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IndexArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Index resource in Oracle Cloud Infrastructure NoSQL Database service.

        Create a new index on the table identified by tableNameOrId.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_index = oci.nosql.Index("testIndex",
            keys=[oci.nosql.IndexKeyArgs(
                column_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                json_field_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                json_path=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            )],
            table_name_or_id=oci_nosql_table_name_or["test_table_name_or"]["id"],
            compartment_id=var["compartment_id"],
            is_if_not_exists=var["index_is_if_not_exists"])
        ```

        ## Import

        Indexes can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Nosql/index:Index test_index "tables/{tableNameOrId}/indexes/{indexName}"
        ```

        :param str resource_name: The name of the resource.
        :param IndexArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IndexArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 is_if_not_exists: Optional[pulumi.Input[bool]] = None,
                 keys: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['IndexKeyArgs']]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 table_name_or_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IndexArgs.__new__(IndexArgs)

            __props__.__dict__["compartment_id"] = compartment_id
            __props__.__dict__["is_if_not_exists"] = is_if_not_exists
            if keys is None and not opts.urn:
                raise TypeError("Missing required property 'keys'")
            __props__.__dict__["keys"] = keys
            __props__.__dict__["name"] = name
            if table_name_or_id is None and not opts.urn:
                raise TypeError("Missing required property 'table_name_or_id'")
            __props__.__dict__["table_name_or_id"] = table_name_or_id
            __props__.__dict__["lifecycle_details"] = None
            __props__.__dict__["state"] = None
            __props__.__dict__["table_id"] = None
            __props__.__dict__["table_name"] = None
        super(Index, __self__).__init__(
            'oci:Nosql/index:Index',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            compartment_id: Optional[pulumi.Input[str]] = None,
            is_if_not_exists: Optional[pulumi.Input[bool]] = None,
            keys: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['IndexKeyArgs']]]]] = None,
            lifecycle_details: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            state: Optional[pulumi.Input[str]] = None,
            table_id: Optional[pulumi.Input[str]] = None,
            table_name: Optional[pulumi.Input[str]] = None,
            table_name_or_id: Optional[pulumi.Input[str]] = None) -> 'Index':
        """
        Get an existing Index resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] compartment_id: The OCID of the table's compartment.  Required if the tableNameOrId path parameter is a table name. Optional if tableNameOrId is an OCID.  If tableNameOrId is an OCID, and compartmentId is supplied, the latter must match the identified table's compartmentId.
        :param pulumi.Input[bool] is_if_not_exists: If true, the operation completes successfully even when the index exists.  Otherwise, an attempt to create an index that already exists will return an error.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['IndexKeyArgs']]]] keys: A set of keys for a secondary index.
        :param pulumi.Input[str] lifecycle_details: A message describing the current state in more detail.
        :param pulumi.Input[str] name: Index name.
        :param pulumi.Input[str] state: The state of an index.
        :param pulumi.Input[str] table_id: the OCID of the table to which this index belongs.
        :param pulumi.Input[str] table_name: The name of the table to which this index belongs.
        :param pulumi.Input[str] table_name_or_id: A table name within the compartment, or a table OCID.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IndexState.__new__(_IndexState)

        __props__.__dict__["compartment_id"] = compartment_id
        __props__.__dict__["is_if_not_exists"] = is_if_not_exists
        __props__.__dict__["keys"] = keys
        __props__.__dict__["lifecycle_details"] = lifecycle_details
        __props__.__dict__["name"] = name
        __props__.__dict__["state"] = state
        __props__.__dict__["table_id"] = table_id
        __props__.__dict__["table_name"] = table_name
        __props__.__dict__["table_name_or_id"] = table_name_or_id
        return Index(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Output[str]:
        """
        The OCID of the table's compartment.  Required if the tableNameOrId path parameter is a table name. Optional if tableNameOrId is an OCID.  If tableNameOrId is an OCID, and compartmentId is supplied, the latter must match the identified table's compartmentId.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="isIfNotExists")
    def is_if_not_exists(self) -> pulumi.Output[bool]:
        """
        If true, the operation completes successfully even when the index exists.  Otherwise, an attempt to create an index that already exists will return an error.
        """
        return pulumi.get(self, "is_if_not_exists")

    @property
    @pulumi.getter
    def keys(self) -> pulumi.Output[Sequence['outputs.IndexKey']]:
        """
        A set of keys for a secondary index.
        """
        return pulumi.get(self, "keys")

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> pulumi.Output[str]:
        """
        A message describing the current state in more detail.
        """
        return pulumi.get(self, "lifecycle_details")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Index name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        """
        The state of an index.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="tableId")
    def table_id(self) -> pulumi.Output[str]:
        """
        the OCID of the table to which this index belongs.
        """
        return pulumi.get(self, "table_id")

    @property
    @pulumi.getter(name="tableName")
    def table_name(self) -> pulumi.Output[str]:
        """
        The name of the table to which this index belongs.
        """
        return pulumi.get(self, "table_name")

    @property
    @pulumi.getter(name="tableNameOrId")
    def table_name_or_id(self) -> pulumi.Output[str]:
        """
        A table name within the compartment, or a table OCID.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "table_name_or_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetFusionEnvironmentScheduledActivityResult',
    'AwaitableGetFusionEnvironmentScheduledActivityResult',
    'get_fusion_environment_scheduled_activity',
    'get_fusion_environment_scheduled_activity_output',
]

@pulumi.output_type
class GetFusionEnvironmentScheduledActivityResult:
    """
    A collection of values returned by getFusionEnvironmentScheduledActivity.
    """
    def __init__(__self__, actions=None, delay_in_hours=None, display_name=None, fusion_environment_id=None, id=None, lifecycle_details=None, run_cycle=None, scheduled_activity_id=None, service_availability=None, state=None, time_created=None, time_expected_finish=None, time_finished=None, time_scheduled_start=None, time_updated=None):
        if actions and not isinstance(actions, list):
            raise TypeError("Expected argument 'actions' to be a list")
        pulumi.set(__self__, "actions", actions)
        if delay_in_hours and not isinstance(delay_in_hours, int):
            raise TypeError("Expected argument 'delay_in_hours' to be a int")
        pulumi.set(__self__, "delay_in_hours", delay_in_hours)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if fusion_environment_id and not isinstance(fusion_environment_id, str):
            raise TypeError("Expected argument 'fusion_environment_id' to be a str")
        pulumi.set(__self__, "fusion_environment_id", fusion_environment_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if lifecycle_details and not isinstance(lifecycle_details, str):
            raise TypeError("Expected argument 'lifecycle_details' to be a str")
        pulumi.set(__self__, "lifecycle_details", lifecycle_details)
        if run_cycle and not isinstance(run_cycle, str):
            raise TypeError("Expected argument 'run_cycle' to be a str")
        pulumi.set(__self__, "run_cycle", run_cycle)
        if scheduled_activity_id and not isinstance(scheduled_activity_id, str):
            raise TypeError("Expected argument 'scheduled_activity_id' to be a str")
        pulumi.set(__self__, "scheduled_activity_id", scheduled_activity_id)
        if service_availability and not isinstance(service_availability, str):
            raise TypeError("Expected argument 'service_availability' to be a str")
        pulumi.set(__self__, "service_availability", service_availability)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)
        if time_expected_finish and not isinstance(time_expected_finish, str):
            raise TypeError("Expected argument 'time_expected_finish' to be a str")
        pulumi.set(__self__, "time_expected_finish", time_expected_finish)
        if time_finished and not isinstance(time_finished, str):
            raise TypeError("Expected argument 'time_finished' to be a str")
        pulumi.set(__self__, "time_finished", time_finished)
        if time_scheduled_start and not isinstance(time_scheduled_start, str):
            raise TypeError("Expected argument 'time_scheduled_start' to be a str")
        pulumi.set(__self__, "time_scheduled_start", time_scheduled_start)
        if time_updated and not isinstance(time_updated, str):
            raise TypeError("Expected argument 'time_updated' to be a str")
        pulumi.set(__self__, "time_updated", time_updated)

    @property
    @pulumi.getter
    def actions(self) -> Sequence['outputs.GetFusionEnvironmentScheduledActivityActionResult']:
        """
        List of actions
        """
        return pulumi.get(self, "actions")

    @property
    @pulumi.getter(name="delayInHours")
    def delay_in_hours(self) -> int:
        """
        Cumulative delay hours
        """
        return pulumi.get(self, "delay_in_hours")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        scheduled activity display name, can be renamed.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="fusionEnvironmentId")
    def fusion_environment_id(self) -> str:
        """
        FAaaS Environment Identifier.
        """
        return pulumi.get(self, "fusion_environment_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> str:
        """
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
        """
        return pulumi.get(self, "lifecycle_details")

    @property
    @pulumi.getter(name="runCycle")
    def run_cycle(self) -> str:
        """
        run cadence.
        """
        return pulumi.get(self, "run_cycle")

    @property
    @pulumi.getter(name="scheduledActivityId")
    def scheduled_activity_id(self) -> str:
        return pulumi.get(self, "scheduled_activity_id")

    @property
    @pulumi.getter(name="serviceAvailability")
    def service_availability(self) -> str:
        """
        Service availability / impact during scheduled activity execution up down
        """
        return pulumi.get(self, "service_availability")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The current state of the scheduledActivity.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The time the scheduled activity record was created. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeExpectedFinish")
    def time_expected_finish(self) -> str:
        """
        Current time the scheduled activity is scheduled to end. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_expected_finish")

    @property
    @pulumi.getter(name="timeFinished")
    def time_finished(self) -> str:
        """
        The time the scheduled activity actually completed / cancelled / failed. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_finished")

    @property
    @pulumi.getter(name="timeScheduledStart")
    def time_scheduled_start(self) -> str:
        """
        Current time the scheduled activity is scheduled to start. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_scheduled_start")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> str:
        """
        The time the scheduled activity record was updated. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_updated")


class AwaitableGetFusionEnvironmentScheduledActivityResult(GetFusionEnvironmentScheduledActivityResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFusionEnvironmentScheduledActivityResult(
            actions=self.actions,
            delay_in_hours=self.delay_in_hours,
            display_name=self.display_name,
            fusion_environment_id=self.fusion_environment_id,
            id=self.id,
            lifecycle_details=self.lifecycle_details,
            run_cycle=self.run_cycle,
            scheduled_activity_id=self.scheduled_activity_id,
            service_availability=self.service_availability,
            state=self.state,
            time_created=self.time_created,
            time_expected_finish=self.time_expected_finish,
            time_finished=self.time_finished,
            time_scheduled_start=self.time_scheduled_start,
            time_updated=self.time_updated)


def get_fusion_environment_scheduled_activity(fusion_environment_id: Optional[str] = None,
                                              scheduled_activity_id: Optional[str] = None,
                                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFusionEnvironmentScheduledActivityResult:
    """
    This data source provides details about a specific Fusion Environment Scheduled Activity resource in Oracle Cloud Infrastructure Fusion Apps service.

    Gets a ScheduledActivity by identifier

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_fusion_environment_scheduled_activity = oci.Functions.get_fusion_environment_scheduled_activity(fusion_environment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        scheduled_activity_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str fusion_environment_id: unique FusionEnvironment identifier
    :param str scheduled_activity_id: Unique ScheduledActivity identifier.
    """
    __args__ = dict()
    __args__['fusionEnvironmentId'] = fusion_environment_id
    __args__['scheduledActivityId'] = scheduled_activity_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Functions/getFusionEnvironmentScheduledActivity:getFusionEnvironmentScheduledActivity', __args__, opts=opts, typ=GetFusionEnvironmentScheduledActivityResult).value

    return AwaitableGetFusionEnvironmentScheduledActivityResult(
        actions=__ret__.actions,
        delay_in_hours=__ret__.delay_in_hours,
        display_name=__ret__.display_name,
        fusion_environment_id=__ret__.fusion_environment_id,
        id=__ret__.id,
        lifecycle_details=__ret__.lifecycle_details,
        run_cycle=__ret__.run_cycle,
        scheduled_activity_id=__ret__.scheduled_activity_id,
        service_availability=__ret__.service_availability,
        state=__ret__.state,
        time_created=__ret__.time_created,
        time_expected_finish=__ret__.time_expected_finish,
        time_finished=__ret__.time_finished,
        time_scheduled_start=__ret__.time_scheduled_start,
        time_updated=__ret__.time_updated)


@_utilities.lift_output_func(get_fusion_environment_scheduled_activity)
def get_fusion_environment_scheduled_activity_output(fusion_environment_id: Optional[pulumi.Input[str]] = None,
                                                     scheduled_activity_id: Optional[pulumi.Input[str]] = None,
                                                     opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetFusionEnvironmentScheduledActivityResult]:
    """
    This data source provides details about a specific Fusion Environment Scheduled Activity resource in Oracle Cloud Infrastructure Fusion Apps service.

    Gets a ScheduledActivity by identifier

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_fusion_environment_scheduled_activity = oci.Functions.get_fusion_environment_scheduled_activity(fusion_environment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        scheduled_activity_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str fusion_environment_id: unique FusionEnvironment identifier
    :param str scheduled_activity_id: Unique ScheduledActivity identifier.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetVmClusterNetworksResult',
    'AwaitableGetVmClusterNetworksResult',
    'get_vm_cluster_networks',
    'get_vm_cluster_networks_output',
]

@pulumi.output_type
class GetVmClusterNetworksResult:
    """
    A collection of values returned by getVmClusterNetworks.
    """
    def __init__(__self__, compartment_id=None, display_name=None, exadata_infrastructure_id=None, filters=None, id=None, state=None, vm_cluster_networks=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if exadata_infrastructure_id and not isinstance(exadata_infrastructure_id, str):
            raise TypeError("Expected argument 'exadata_infrastructure_id' to be a str")
        pulumi.set(__self__, "exadata_infrastructure_id", exadata_infrastructure_id)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if vm_cluster_networks and not isinstance(vm_cluster_networks, list):
            raise TypeError("Expected argument 'vm_cluster_networks' to be a list")
        pulumi.set(__self__, "vm_cluster_networks", vm_cluster_networks)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        """
        The user-friendly name for the VM cluster network. The name does not need to be unique.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="exadataInfrastructureId")
    def exadata_infrastructure_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Exadata infrastructure.
        """
        return pulumi.get(self, "exadata_infrastructure_id")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetVmClusterNetworksFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        The current state of the VM cluster network nodes. CREATING - The resource is being created REQUIRES_VALIDATION - The resource is created and may not be usable until it is validated. VALIDATING - The resource is being validated and not available to use. VALIDATED - The resource is validated and is available for consumption by VM cluster. VALIDATION_FAILED - The resource validation has failed and might require user input to be corrected. UPDATING - The resource is being updated and not available to use. ALLOCATED - The resource is currently being used by VM cluster. TERMINATING - The resource is being deleted and not available to use. TERMINATED - The resource is deleted and unavailable. FAILED - The resource is in a failed state due to validation or other errors.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="vmClusterNetworks")
    def vm_cluster_networks(self) -> Sequence['outputs.GetVmClusterNetworksVmClusterNetworkResult']:
        """
        The list of vm_cluster_networks.
        """
        return pulumi.get(self, "vm_cluster_networks")


class AwaitableGetVmClusterNetworksResult(GetVmClusterNetworksResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVmClusterNetworksResult(
            compartment_id=self.compartment_id,
            display_name=self.display_name,
            exadata_infrastructure_id=self.exadata_infrastructure_id,
            filters=self.filters,
            id=self.id,
            state=self.state,
            vm_cluster_networks=self.vm_cluster_networks)


def get_vm_cluster_networks(compartment_id: Optional[str] = None,
                            display_name: Optional[str] = None,
                            exadata_infrastructure_id: Optional[str] = None,
                            filters: Optional[Sequence[pulumi.InputType['GetVmClusterNetworksFilterArgs']]] = None,
                            state: Optional[str] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVmClusterNetworksResult:
    """
    This data source provides the list of Vm Cluster Networks in Oracle Cloud Infrastructure Database service.

    Gets a list of the VM cluster networks in the specified compartment. Applies to Exadata Cloud@Customer instances only.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_vm_cluster_networks = oci.Database.get_vm_cluster_networks(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        exadata_infrastructure_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The compartment [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str display_name: A filter to return only resources that match the entire display name given. The match is not case sensitive.
    :param str exadata_infrastructure_id: The Exadata infrastructure [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str state: A filter to return only resources that match the given lifecycle state exactly.
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['displayName'] = display_name
    __args__['exadataInfrastructureId'] = exadata_infrastructure_id
    __args__['filters'] = filters
    __args__['state'] = state
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Database/getVmClusterNetworks:getVmClusterNetworks', __args__, opts=opts, typ=GetVmClusterNetworksResult).value

    return AwaitableGetVmClusterNetworksResult(
        compartment_id=__ret__.compartment_id,
        display_name=__ret__.display_name,
        exadata_infrastructure_id=__ret__.exadata_infrastructure_id,
        filters=__ret__.filters,
        id=__ret__.id,
        state=__ret__.state,
        vm_cluster_networks=__ret__.vm_cluster_networks)


@_utilities.lift_output_func(get_vm_cluster_networks)
def get_vm_cluster_networks_output(compartment_id: Optional[pulumi.Input[str]] = None,
                                   display_name: Optional[pulumi.Input[Optional[str]]] = None,
                                   exadata_infrastructure_id: Optional[pulumi.Input[str]] = None,
                                   filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetVmClusterNetworksFilterArgs']]]]] = None,
                                   state: Optional[pulumi.Input[Optional[str]]] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetVmClusterNetworksResult]:
    """
    This data source provides the list of Vm Cluster Networks in Oracle Cloud Infrastructure Database service.

    Gets a list of the VM cluster networks in the specified compartment. Applies to Exadata Cloud@Customer instances only.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_vm_cluster_networks = oci.Database.get_vm_cluster_networks(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        exadata_infrastructure_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The compartment [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str display_name: A filter to return only resources that match the entire display name given. The match is not case sensitive.
    :param str exadata_infrastructure_id: The Exadata infrastructure [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str state: A filter to return only resources that match the given lifecycle state exactly.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetManagementAgentInstallKeysResult',
    'AwaitableGetManagementAgentInstallKeysResult',
    'get_management_agent_install_keys',
    'get_management_agent_install_keys_output',
]

@pulumi.output_type
class GetManagementAgentInstallKeysResult:
    """
    A collection of values returned by getManagementAgentInstallKeys.
    """
    def __init__(__self__, access_level=None, compartment_id=None, compartment_id_in_subtree=None, display_name=None, filters=None, id=None, management_agent_install_keys=None, state=None):
        if access_level and not isinstance(access_level, str):
            raise TypeError("Expected argument 'access_level' to be a str")
        pulumi.set(__self__, "access_level", access_level)
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if compartment_id_in_subtree and not isinstance(compartment_id_in_subtree, bool):
            raise TypeError("Expected argument 'compartment_id_in_subtree' to be a bool")
        pulumi.set(__self__, "compartment_id_in_subtree", compartment_id_in_subtree)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if management_agent_install_keys and not isinstance(management_agent_install_keys, list):
            raise TypeError("Expected argument 'management_agent_install_keys' to be a list")
        pulumi.set(__self__, "management_agent_install_keys", management_agent_install_keys)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter(name="accessLevel")
    def access_level(self) -> Optional[str]:
        return pulumi.get(self, "access_level")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        Compartment Identifier
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="compartmentIdInSubtree")
    def compartment_id_in_subtree(self) -> Optional[bool]:
        return pulumi.get(self, "compartment_id_in_subtree")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        """
        Management Agent Install Key Name
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetManagementAgentInstallKeysFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="managementAgentInstallKeys")
    def management_agent_install_keys(self) -> Sequence['outputs.GetManagementAgentInstallKeysManagementAgentInstallKeyResult']:
        """
        The list of management_agent_install_keys.
        """
        return pulumi.get(self, "management_agent_install_keys")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        Status of Key
        """
        return pulumi.get(self, "state")


class AwaitableGetManagementAgentInstallKeysResult(GetManagementAgentInstallKeysResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetManagementAgentInstallKeysResult(
            access_level=self.access_level,
            compartment_id=self.compartment_id,
            compartment_id_in_subtree=self.compartment_id_in_subtree,
            display_name=self.display_name,
            filters=self.filters,
            id=self.id,
            management_agent_install_keys=self.management_agent_install_keys,
            state=self.state)


def get_management_agent_install_keys(access_level: Optional[str] = None,
                                      compartment_id: Optional[str] = None,
                                      compartment_id_in_subtree: Optional[bool] = None,
                                      display_name: Optional[str] = None,
                                      filters: Optional[Sequence[pulumi.InputType['GetManagementAgentInstallKeysFilterArgs']]] = None,
                                      state: Optional[str] = None,
                                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetManagementAgentInstallKeysResult:
    """
    This data source provides the list of Management Agent Install Keys in Oracle Cloud Infrastructure Management Agent service.

    Returns a list of Management Agent installed Keys.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_management_agent_install_keys = oci.ManagementAgent.get_management_agent_install_keys(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        access_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        compartment_id_in_subtree=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str access_level: Value of this is always "ACCESSIBLE" and any other value is not supported.
    :param str compartment_id: The OCID of the compartment to which a request will be scoped.
    :param bool compartment_id_in_subtree: if set to true then it fetches resources for all compartments where user has access to else only on the compartment specified.
    :param str display_name: The display name for which the Key needs to be listed.
    :param str state: Filter to return only Management Agents in the particular lifecycle state.
    """
    __args__ = dict()
    __args__['accessLevel'] = access_level
    __args__['compartmentId'] = compartment_id
    __args__['compartmentIdInSubtree'] = compartment_id_in_subtree
    __args__['displayName'] = display_name
    __args__['filters'] = filters
    __args__['state'] = state
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:ManagementAgent/getManagementAgentInstallKeys:getManagementAgentInstallKeys', __args__, opts=opts, typ=GetManagementAgentInstallKeysResult).value

    return AwaitableGetManagementAgentInstallKeysResult(
        access_level=__ret__.access_level,
        compartment_id=__ret__.compartment_id,
        compartment_id_in_subtree=__ret__.compartment_id_in_subtree,
        display_name=__ret__.display_name,
        filters=__ret__.filters,
        id=__ret__.id,
        management_agent_install_keys=__ret__.management_agent_install_keys,
        state=__ret__.state)


@_utilities.lift_output_func(get_management_agent_install_keys)
def get_management_agent_install_keys_output(access_level: Optional[pulumi.Input[Optional[str]]] = None,
                                             compartment_id: Optional[pulumi.Input[str]] = None,
                                             compartment_id_in_subtree: Optional[pulumi.Input[Optional[bool]]] = None,
                                             display_name: Optional[pulumi.Input[Optional[str]]] = None,
                                             filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetManagementAgentInstallKeysFilterArgs']]]]] = None,
                                             state: Optional[pulumi.Input[Optional[str]]] = None,
                                             opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetManagementAgentInstallKeysResult]:
    """
    This data source provides the list of Management Agent Install Keys in Oracle Cloud Infrastructure Management Agent service.

    Returns a list of Management Agent installed Keys.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_management_agent_install_keys = oci.ManagementAgent.get_management_agent_install_keys(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        access_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        compartment_id_in_subtree=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str access_level: Value of this is always "ACCESSIBLE" and any other value is not supported.
    :param str compartment_id: The OCID of the compartment to which a request will be scoped.
    :param bool compartment_id_in_subtree: if set to true then it fetches resources for all compartments where user has access to else only on the compartment specified.
    :param str display_name: The display name for which the Key needs to be listed.
    :param str state: Filter to return only Management Agents in the particular lifecycle state.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetManagementAgentResult',
    'AwaitableGetManagementAgentResult',
    'get_management_agent',
    'get_management_agent_output',
]

@pulumi.output_type
class GetManagementAgentResult:
    """
    A collection of values returned by getManagementAgent.
    """
    def __init__(__self__, availability_status=None, compartment_id=None, defined_tags=None, deploy_plugins_ids=None, display_name=None, freeform_tags=None, host=None, host_id=None, id=None, install_key_id=None, install_path=None, install_type=None, is_agent_auto_upgradable=None, is_customer_deployed=None, lifecycle_details=None, managed_agent_id=None, management_agent_id=None, management_agent_properties=None, platform_name=None, platform_type=None, platform_version=None, plugin_lists=None, resource_artifact_version=None, state=None, time_created=None, time_last_heartbeat=None, time_updated=None, version=None):
        if availability_status and not isinstance(availability_status, str):
            raise TypeError("Expected argument 'availability_status' to be a str")
        pulumi.set(__self__, "availability_status", availability_status)
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if defined_tags and not isinstance(defined_tags, dict):
            raise TypeError("Expected argument 'defined_tags' to be a dict")
        pulumi.set(__self__, "defined_tags", defined_tags)
        if deploy_plugins_ids and not isinstance(deploy_plugins_ids, list):
            raise TypeError("Expected argument 'deploy_plugins_ids' to be a list")
        pulumi.set(__self__, "deploy_plugins_ids", deploy_plugins_ids)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if freeform_tags and not isinstance(freeform_tags, dict):
            raise TypeError("Expected argument 'freeform_tags' to be a dict")
        pulumi.set(__self__, "freeform_tags", freeform_tags)
        if host and not isinstance(host, str):
            raise TypeError("Expected argument 'host' to be a str")
        pulumi.set(__self__, "host", host)
        if host_id and not isinstance(host_id, str):
            raise TypeError("Expected argument 'host_id' to be a str")
        pulumi.set(__self__, "host_id", host_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if install_key_id and not isinstance(install_key_id, str):
            raise TypeError("Expected argument 'install_key_id' to be a str")
        pulumi.set(__self__, "install_key_id", install_key_id)
        if install_path and not isinstance(install_path, str):
            raise TypeError("Expected argument 'install_path' to be a str")
        pulumi.set(__self__, "install_path", install_path)
        if install_type and not isinstance(install_type, str):
            raise TypeError("Expected argument 'install_type' to be a str")
        pulumi.set(__self__, "install_type", install_type)
        if is_agent_auto_upgradable and not isinstance(is_agent_auto_upgradable, bool):
            raise TypeError("Expected argument 'is_agent_auto_upgradable' to be a bool")
        pulumi.set(__self__, "is_agent_auto_upgradable", is_agent_auto_upgradable)
        if is_customer_deployed and not isinstance(is_customer_deployed, bool):
            raise TypeError("Expected argument 'is_customer_deployed' to be a bool")
        pulumi.set(__self__, "is_customer_deployed", is_customer_deployed)
        if lifecycle_details and not isinstance(lifecycle_details, str):
            raise TypeError("Expected argument 'lifecycle_details' to be a str")
        pulumi.set(__self__, "lifecycle_details", lifecycle_details)
        if managed_agent_id and not isinstance(managed_agent_id, str):
            raise TypeError("Expected argument 'managed_agent_id' to be a str")
        pulumi.set(__self__, "managed_agent_id", managed_agent_id)
        if management_agent_id and not isinstance(management_agent_id, str):
            raise TypeError("Expected argument 'management_agent_id' to be a str")
        pulumi.set(__self__, "management_agent_id", management_agent_id)
        if management_agent_properties and not isinstance(management_agent_properties, list):
            raise TypeError("Expected argument 'management_agent_properties' to be a list")
        pulumi.set(__self__, "management_agent_properties", management_agent_properties)
        if platform_name and not isinstance(platform_name, str):
            raise TypeError("Expected argument 'platform_name' to be a str")
        pulumi.set(__self__, "platform_name", platform_name)
        if platform_type and not isinstance(platform_type, str):
            raise TypeError("Expected argument 'platform_type' to be a str")
        pulumi.set(__self__, "platform_type", platform_type)
        if platform_version and not isinstance(platform_version, str):
            raise TypeError("Expected argument 'platform_version' to be a str")
        pulumi.set(__self__, "platform_version", platform_version)
        if plugin_lists and not isinstance(plugin_lists, list):
            raise TypeError("Expected argument 'plugin_lists' to be a list")
        pulumi.set(__self__, "plugin_lists", plugin_lists)
        if resource_artifact_version and not isinstance(resource_artifact_version, str):
            raise TypeError("Expected argument 'resource_artifact_version' to be a str")
        pulumi.set(__self__, "resource_artifact_version", resource_artifact_version)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)
        if time_last_heartbeat and not isinstance(time_last_heartbeat, str):
            raise TypeError("Expected argument 'time_last_heartbeat' to be a str")
        pulumi.set(__self__, "time_last_heartbeat", time_last_heartbeat)
        if time_updated and not isinstance(time_updated, str):
            raise TypeError("Expected argument 'time_updated' to be a str")
        pulumi.set(__self__, "time_updated", time_updated)
        if version and not isinstance(version, str):
            raise TypeError("Expected argument 'version' to be a str")
        pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter(name="availabilityStatus")
    def availability_status(self) -> str:
        """
        The current availability status of managementAgent
        """
        return pulumi.get(self, "availability_status")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        Compartment Identifier
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Mapping[str, Any]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="deployPluginsIds")
    def deploy_plugins_ids(self) -> Sequence[str]:
        return pulumi.get(self, "deploy_plugins_ids")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        Management Agent Name
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Mapping[str, Any]:
        """
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter
    def host(self) -> str:
        """
        Management Agent host machine name
        """
        return pulumi.get(self, "host")

    @property
    @pulumi.getter(name="hostId")
    def host_id(self) -> str:
        """
        Host resource ocid
        """
        return pulumi.get(self, "host_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        agent identifier
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="installKeyId")
    def install_key_id(self) -> str:
        """
        agent install key identifier
        """
        return pulumi.get(self, "install_key_id")

    @property
    @pulumi.getter(name="installPath")
    def install_path(self) -> str:
        """
        Path where Management Agent is installed
        """
        return pulumi.get(self, "install_path")

    @property
    @pulumi.getter(name="installType")
    def install_type(self) -> str:
        """
        The install type, either AGENT or GATEWAY
        """
        return pulumi.get(self, "install_type")

    @property
    @pulumi.getter(name="isAgentAutoUpgradable")
    def is_agent_auto_upgradable(self) -> bool:
        """
        true if the agent can be upgraded automatically; false if it must be upgraded manually. This flag is derived from the tenancy level auto upgrade preference.
        """
        return pulumi.get(self, "is_agent_auto_upgradable")

    @property
    @pulumi.getter(name="isCustomerDeployed")
    def is_customer_deployed(self) -> bool:
        """
        true, if the agent image is manually downloaded and installed. false, if the agent is deployed as a plugin in Oracle Cloud Agent.
        """
        return pulumi.get(self, "is_customer_deployed")

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> str:
        """
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
        """
        return pulumi.get(self, "lifecycle_details")

    @property
    @pulumi.getter(name="managedAgentId")
    def managed_agent_id(self) -> str:
        return pulumi.get(self, "managed_agent_id")

    @property
    @pulumi.getter(name="managementAgentId")
    def management_agent_id(self) -> str:
        return pulumi.get(self, "management_agent_id")

    @property
    @pulumi.getter(name="managementAgentProperties")
    def management_agent_properties(self) -> Sequence['outputs.GetManagementAgentManagementAgentPropertyResult']:
        """
        Additional properties for this Management Agent
        """
        return pulumi.get(self, "management_agent_properties")

    @property
    @pulumi.getter(name="platformName")
    def platform_name(self) -> str:
        """
        Platform Name
        """
        return pulumi.get(self, "platform_name")

    @property
    @pulumi.getter(name="platformType")
    def platform_type(self) -> str:
        """
        Platform Type
        """
        return pulumi.get(self, "platform_type")

    @property
    @pulumi.getter(name="platformVersion")
    def platform_version(self) -> str:
        """
        Platform Version
        """
        return pulumi.get(self, "platform_version")

    @property
    @pulumi.getter(name="pluginLists")
    def plugin_lists(self) -> Sequence['outputs.GetManagementAgentPluginListResult']:
        """
        list of managementAgentPlugins associated with the agent
        """
        return pulumi.get(self, "plugin_lists")

    @property
    @pulumi.getter(name="resourceArtifactVersion")
    def resource_artifact_version(self) -> str:
        """
        Version of the deployment artifact instantiated by this Management Agent. The format for Standalone resourceMode is YYMMDD.HHMM, and the format for other modes (whose artifacts are based upon Standalone but can advance independently) is YYMMDD.HHMM.VVVVVVVVVVVV. VVVVVVVVVVVV is always a numeric value between 000000000000 and 999999999999
        """
        return pulumi.get(self, "resource_artifact_version")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The current state of managementAgent
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The time the Management Agent was created. An RFC3339 formatted datetime string
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeLastHeartbeat")
    def time_last_heartbeat(self) -> str:
        """
        The time the Management Agent has last recorded its health status in telemetry. This value will be null if the agent has not recorded its health status in last 7 days. An RFC3339 formatted datetime string
        """
        return pulumi.get(self, "time_last_heartbeat")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> str:
        """
        The time the Management Agent was last updated. An RFC3339 formatted datetime string
        """
        return pulumi.get(self, "time_updated")

    @property
    @pulumi.getter
    def version(self) -> str:
        """
        Management Agent Version
        """
        return pulumi.get(self, "version")


class AwaitableGetManagementAgentResult(GetManagementAgentResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetManagementAgentResult(
            availability_status=self.availability_status,
            compartment_id=self.compartment_id,
            defined_tags=self.defined_tags,
            deploy_plugins_ids=self.deploy_plugins_ids,
            display_name=self.display_name,
            freeform_tags=self.freeform_tags,
            host=self.host,
            host_id=self.host_id,
            id=self.id,
            install_key_id=self.install_key_id,
            install_path=self.install_path,
            install_type=self.install_type,
            is_agent_auto_upgradable=self.is_agent_auto_upgradable,
            is_customer_deployed=self.is_customer_deployed,
            lifecycle_details=self.lifecycle_details,
            managed_agent_id=self.managed_agent_id,
            management_agent_id=self.management_agent_id,
            management_agent_properties=self.management_agent_properties,
            platform_name=self.platform_name,
            platform_type=self.platform_type,
            platform_version=self.platform_version,
            plugin_lists=self.plugin_lists,
            resource_artifact_version=self.resource_artifact_version,
            state=self.state,
            time_created=self.time_created,
            time_last_heartbeat=self.time_last_heartbeat,
            time_updated=self.time_updated,
            version=self.version)


def get_management_agent(management_agent_id: Optional[str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetManagementAgentResult:
    """
    This data source provides details about a specific Management Agent resource in Oracle Cloud Infrastructure Management Agent service.

    Gets complete details of the inventory of a given agent id

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_management_agent = oci.ManagementAgent.get_management_agent(management_agent_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str management_agent_id: Unique Management Agent identifier
    """
    __args__ = dict()
    __args__['managementAgentId'] = management_agent_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:ManagementAgent/getManagementAgent:getManagementAgent', __args__, opts=opts, typ=GetManagementAgentResult).value

    return AwaitableGetManagementAgentResult(
        availability_status=__ret__.availability_status,
        compartment_id=__ret__.compartment_id,
        defined_tags=__ret__.defined_tags,
        deploy_plugins_ids=__ret__.deploy_plugins_ids,
        display_name=__ret__.display_name,
        freeform_tags=__ret__.freeform_tags,
        host=__ret__.host,
        host_id=__ret__.host_id,
        id=__ret__.id,
        install_key_id=__ret__.install_key_id,
        install_path=__ret__.install_path,
        install_type=__ret__.install_type,
        is_agent_auto_upgradable=__ret__.is_agent_auto_upgradable,
        is_customer_deployed=__ret__.is_customer_deployed,
        lifecycle_details=__ret__.lifecycle_details,
        managed_agent_id=__ret__.managed_agent_id,
        management_agent_id=__ret__.management_agent_id,
        management_agent_properties=__ret__.management_agent_properties,
        platform_name=__ret__.platform_name,
        platform_type=__ret__.platform_type,
        platform_version=__ret__.platform_version,
        plugin_lists=__ret__.plugin_lists,
        resource_artifact_version=__ret__.resource_artifact_version,
        state=__ret__.state,
        time_created=__ret__.time_created,
        time_last_heartbeat=__ret__.time_last_heartbeat,
        time_updated=__ret__.time_updated,
        version=__ret__.version)


@_utilities.lift_output_func(get_management_agent)
def get_management_agent_output(management_agent_id: Optional[pulumi.Input[str]] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetManagementAgentResult]:
    """
    This data source provides details about a specific Management Agent resource in Oracle Cloud Infrastructure Management Agent service.

    Gets complete details of the inventory of a given agent id

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_management_agent = oci.ManagementAgent.get_management_agent(management_agent_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str management_agent_id: Unique Management Agent identifier
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['InstanceArgs', 'Instance']

@pulumi.input_type
class InstanceArgs:
    def __init__(__self__, *,
                 admin_email: pulumi.Input[str],
                 compartment_id: pulumi.Input[str],
                 idcs_access_token: pulumi.Input[str],
                 object_storage_namespace: pulumi.Input[str],
                 tenancy_id: pulumi.Input[str],
                 tenancy_name: pulumi.Input[str],
                 add_on_features: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 dr_region: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 instance_access_type: Optional[pulumi.Input[str]] = None,
                 instance_license_type: Optional[pulumi.Input[str]] = None,
                 instance_usage_type: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 upgrade_schedule: Optional[pulumi.Input[str]] = None,
                 waf_primary_domain: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Instance resource.
        :param pulumi.Input[str] admin_email: Admin Email for Notification
        :param pulumi.Input[str] compartment_id: (Updatable) Compartment Identifier
        :param pulumi.Input[str] idcs_access_token: Identity Cloud Service access token identifying a stripe and service administrator user
        :param pulumi.Input[str] object_storage_namespace: Object Storage Namespace of Tenancy
        :param pulumi.Input[str] tenancy_id: Tenancy Identifier
        :param pulumi.Input[str] tenancy_name: Tenancy Name
        :param pulumi.Input[Sequence[pulumi.Input[str]]] add_on_features: (Updatable) a list of add-on features for the ocm instance
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"foo-namespace.bar-key": "value"}`
        :param pulumi.Input[str] description: (Updatable) OceInstance description
        :param pulumi.Input[str] dr_region: (Updatable) disaster recovery paired ragion name
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        :param pulumi.Input[str] instance_access_type: Flag indicating whether the instance access is private or public
        :param pulumi.Input[str] instance_license_type: (Updatable) Flag indicating whether the instance license is new cloud or bring your own license
        :param pulumi.Input[str] instance_usage_type: (Updatable) Instance type based on its usage
        :param pulumi.Input[str] name: OceInstance Name
        :param pulumi.Input[str] upgrade_schedule: Upgrade schedule type representing service to be upgraded immediately whenever latest version is released or delay upgrade of the service to previous released version
        :param pulumi.Input[str] waf_primary_domain: (Updatable) Web Application Firewall(WAF) primary domain
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        pulumi.set(__self__, "admin_email", admin_email)
        pulumi.set(__self__, "compartment_id", compartment_id)
        pulumi.set(__self__, "idcs_access_token", idcs_access_token)
        pulumi.set(__self__, "object_storage_namespace", object_storage_namespace)
        pulumi.set(__self__, "tenancy_id", tenancy_id)
        pulumi.set(__self__, "tenancy_name", tenancy_name)
        if add_on_features is not None:
            pulumi.set(__self__, "add_on_features", add_on_features)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dr_region is not None:
            pulumi.set(__self__, "dr_region", dr_region)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if instance_access_type is not None:
            pulumi.set(__self__, "instance_access_type", instance_access_type)
        if instance_license_type is not None:
            pulumi.set(__self__, "instance_license_type", instance_license_type)
        if instance_usage_type is not None:
            pulumi.set(__self__, "instance_usage_type", instance_usage_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if upgrade_schedule is not None:
            pulumi.set(__self__, "upgrade_schedule", upgrade_schedule)
        if waf_primary_domain is not None:
            pulumi.set(__self__, "waf_primary_domain", waf_primary_domain)

    @property
    @pulumi.getter(name="adminEmail")
    def admin_email(self) -> pulumi.Input[str]:
        """
        Admin Email for Notification
        """
        return pulumi.get(self, "admin_email")

    @admin_email.setter
    def admin_email(self, value: pulumi.Input[str]):
        pulumi.set(self, "admin_email", value)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Input[str]:
        """
        (Updatable) Compartment Identifier
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="idcsAccessToken")
    def idcs_access_token(self) -> pulumi.Input[str]:
        """
        Identity Cloud Service access token identifying a stripe and service administrator user
        """
        return pulumi.get(self, "idcs_access_token")

    @idcs_access_token.setter
    def idcs_access_token(self, value: pulumi.Input[str]):
        pulumi.set(self, "idcs_access_token", value)

    @property
    @pulumi.getter(name="objectStorageNamespace")
    def object_storage_namespace(self) -> pulumi.Input[str]:
        """
        Object Storage Namespace of Tenancy
        """
        return pulumi.get(self, "object_storage_namespace")

    @object_storage_namespace.setter
    def object_storage_namespace(self, value: pulumi.Input[str]):
        pulumi.set(self, "object_storage_namespace", value)

    @property
    @pulumi.getter(name="tenancyId")
    def tenancy_id(self) -> pulumi.Input[str]:
        """
        Tenancy Identifier
        """
        return pulumi.get(self, "tenancy_id")

    @tenancy_id.setter
    def tenancy_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "tenancy_id", value)

    @property
    @pulumi.getter(name="tenancyName")
    def tenancy_name(self) -> pulumi.Input[str]:
        """
        Tenancy Name
        """
        return pulumi.get(self, "tenancy_name")

    @tenancy_name.setter
    def tenancy_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "tenancy_name", value)

    @property
    @pulumi.getter(name="addOnFeatures")
    def add_on_features(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        (Updatable) a list of add-on features for the ocm instance
        """
        return pulumi.get(self, "add_on_features")

    @add_on_features.setter
    def add_on_features(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "add_on_features", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) OceInstance description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="drRegion")
    def dr_region(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) disaster recovery paired ragion name
        """
        return pulumi.get(self, "dr_region")

    @dr_region.setter
    def dr_region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dr_region", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter(name="instanceAccessType")
    def instance_access_type(self) -> Optional[pulumi.Input[str]]:
        """
        Flag indicating whether the instance access is private or public
        """
        return pulumi.get(self, "instance_access_type")

    @instance_access_type.setter
    def instance_access_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_access_type", value)

    @property
    @pulumi.getter(name="instanceLicenseType")
    def instance_license_type(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Flag indicating whether the instance license is new cloud or bring your own license
        """
        return pulumi.get(self, "instance_license_type")

    @instance_license_type.setter
    def instance_license_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_license_type", value)

    @property
    @pulumi.getter(name="instanceUsageType")
    def instance_usage_type(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Instance type based on its usage
        """
        return pulumi.get(self, "instance_usage_type")

    @instance_usage_type.setter
    def instance_usage_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_usage_type", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        OceInstance Name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="upgradeSchedule")
    def upgrade_schedule(self) -> Optional[pulumi.Input[str]]:
        """
        Upgrade schedule type representing service to be upgraded immediately whenever latest version is released or delay upgrade of the service to previous released version
        """
        return pulumi.get(self, "upgrade_schedule")

    @upgrade_schedule.setter
    def upgrade_schedule(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "upgrade_schedule", value)

    @property
    @pulumi.getter(name="wafPrimaryDomain")
    def waf_primary_domain(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Web Application Firewall(WAF) primary domain


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "waf_primary_domain")

    @waf_primary_domain.setter
    def waf_primary_domain(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "waf_primary_domain", value)


@pulumi.input_type
class _InstanceState:
    def __init__(__self__, *,
                 add_on_features: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 admin_email: Optional[pulumi.Input[str]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 dr_region: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 guid: Optional[pulumi.Input[str]] = None,
                 idcs_access_token: Optional[pulumi.Input[str]] = None,
                 idcs_tenancy: Optional[pulumi.Input[str]] = None,
                 instance_access_type: Optional[pulumi.Input[str]] = None,
                 instance_license_type: Optional[pulumi.Input[str]] = None,
                 instance_usage_type: Optional[pulumi.Input[str]] = None,
                 lifecycle_details: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 object_storage_namespace: Optional[pulumi.Input[str]] = None,
                 service: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 state_message: Optional[pulumi.Input[str]] = None,
                 system_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 tenancy_id: Optional[pulumi.Input[str]] = None,
                 tenancy_name: Optional[pulumi.Input[str]] = None,
                 time_created: Optional[pulumi.Input[str]] = None,
                 time_updated: Optional[pulumi.Input[str]] = None,
                 upgrade_schedule: Optional[pulumi.Input[str]] = None,
                 waf_primary_domain: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Instance resources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] add_on_features: (Updatable) a list of add-on features for the ocm instance
        :param pulumi.Input[str] admin_email: Admin Email for Notification
        :param pulumi.Input[str] compartment_id: (Updatable) Compartment Identifier
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"foo-namespace.bar-key": "value"}`
        :param pulumi.Input[str] description: (Updatable) OceInstance description
        :param pulumi.Input[str] dr_region: (Updatable) disaster recovery paired ragion name
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        :param pulumi.Input[str] guid: Unique GUID identifier that is immutable on creation
        :param pulumi.Input[str] idcs_access_token: Identity Cloud Service access token identifying a stripe and service administrator user
        :param pulumi.Input[str] idcs_tenancy: IDCS Tenancy Identifier
        :param pulumi.Input[str] instance_access_type: Flag indicating whether the instance access is private or public
        :param pulumi.Input[str] instance_license_type: (Updatable) Flag indicating whether the instance license is new cloud or bring your own license
        :param pulumi.Input[str] instance_usage_type: (Updatable) Instance type based on its usage
        :param pulumi.Input[str] lifecycle_details: Details of the current state of the instance lifecycle
        :param pulumi.Input[str] name: OceInstance Name
        :param pulumi.Input[str] object_storage_namespace: Object Storage Namespace of Tenancy
        :param pulumi.Input[Mapping[str, Any]] service: SERVICE data. Example: `{"service": {"IDCS": "value"}}`
        :param pulumi.Input[str] state: The current state of the instance lifecycle.
        :param pulumi.Input[str] state_message: An message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
        :param pulumi.Input[Mapping[str, Any]] system_tags: Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"orcl-cloud.free-tier-retained": "true"}`
        :param pulumi.Input[str] tenancy_id: Tenancy Identifier
        :param pulumi.Input[str] tenancy_name: Tenancy Name
        :param pulumi.Input[str] time_created: The time the the OceInstance was created. An RFC3339 formatted datetime string
        :param pulumi.Input[str] time_updated: The time the OceInstance was updated. An RFC3339 formatted datetime string
        :param pulumi.Input[str] upgrade_schedule: Upgrade schedule type representing service to be upgraded immediately whenever latest version is released or delay upgrade of the service to previous released version
        :param pulumi.Input[str] waf_primary_domain: (Updatable) Web Application Firewall(WAF) primary domain
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        if add_on_features is not None:
            pulumi.set(__self__, "add_on_features", add_on_features)
        if admin_email is not None:
            pulumi.set(__self__, "admin_email", admin_email)
        if compartment_id is not None:
            pulumi.set(__self__, "compartment_id", compartment_id)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dr_region is not None:
            pulumi.set(__self__, "dr_region", dr_region)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if guid is not None:
            pulumi.set(__self__, "guid", guid)
        if idcs_access_token is not None:
            pulumi.set(__self__, "idcs_access_token", idcs_access_token)
        if idcs_tenancy is not None:
            pulumi.set(__self__, "idcs_tenancy", idcs_tenancy)
        if instance_access_type is not None:
            pulumi.set(__self__, "instance_access_type", instance_access_type)
        if instance_license_type is not None:
            pulumi.set(__self__, "instance_license_type", instance_license_type)
        if instance_usage_type is not None:
            pulumi.set(__self__, "instance_usage_type", instance_usage_type)
        if lifecycle_details is not None:
            pulumi.set(__self__, "lifecycle_details", lifecycle_details)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if object_storage_namespace is not None:
            pulumi.set(__self__, "object_storage_namespace", object_storage_namespace)
        if service is not None:
            pulumi.set(__self__, "service", service)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if state_message is not None:
            pulumi.set(__self__, "state_message", state_message)
        if system_tags is not None:
            pulumi.set(__self__, "system_tags", system_tags)
        if tenancy_id is not None:
            pulumi.set(__self__, "tenancy_id", tenancy_id)
        if tenancy_name is not None:
            pulumi.set(__self__, "tenancy_name", tenancy_name)
        if time_created is not None:
            pulumi.set(__self__, "time_created", time_created)
        if time_updated is not None:
            pulumi.set(__self__, "time_updated", time_updated)
        if upgrade_schedule is not None:
            pulumi.set(__self__, "upgrade_schedule", upgrade_schedule)
        if waf_primary_domain is not None:
            pulumi.set(__self__, "waf_primary_domain", waf_primary_domain)

    @property
    @pulumi.getter(name="addOnFeatures")
    def add_on_features(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        (Updatable) a list of add-on features for the ocm instance
        """
        return pulumi.get(self, "add_on_features")

    @add_on_features.setter
    def add_on_features(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "add_on_features", value)

    @property
    @pulumi.getter(name="adminEmail")
    def admin_email(self) -> Optional[pulumi.Input[str]]:
        """
        Admin Email for Notification
        """
        return pulumi.get(self, "admin_email")

    @admin_email.setter
    def admin_email(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "admin_email", value)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Compartment Identifier
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) OceInstance description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="drRegion")
    def dr_region(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) disaster recovery paired ragion name
        """
        return pulumi.get(self, "dr_region")

    @dr_region.setter
    def dr_region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dr_region", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter
    def guid(self) -> Optional[pulumi.Input[str]]:
        """
        Unique GUID identifier that is immutable on creation
        """
        return pulumi.get(self, "guid")

    @guid.setter
    def guid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "guid", value)

    @property
    @pulumi.getter(name="idcsAccessToken")
    def idcs_access_token(self) -> Optional[pulumi.Input[str]]:
        """
        Identity Cloud Service access token identifying a stripe and service administrator user
        """
        return pulumi.get(self, "idcs_access_token")

    @idcs_access_token.setter
    def idcs_access_token(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "idcs_access_token", value)

    @property
    @pulumi.getter(name="idcsTenancy")
    def idcs_tenancy(self) -> Optional[pulumi.Input[str]]:
        """
        IDCS Tenancy Identifier
        """
        return pulumi.get(self, "idcs_tenancy")

    @idcs_tenancy.setter
    def idcs_tenancy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "idcs_tenancy", value)

    @property
    @pulumi.getter(name="instanceAccessType")
    def instance_access_type(self) -> Optional[pulumi.Input[str]]:
        """
        Flag indicating whether the instance access is private or public
        """
        return pulumi.get(self, "instance_access_type")

    @instance_access_type.setter
    def instance_access_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_access_type", value)

    @property
    @pulumi.getter(name="instanceLicenseType")
    def instance_license_type(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Flag indicating whether the instance license is new cloud or bring your own license
        """
        return pulumi.get(self, "instance_license_type")

    @instance_license_type.setter
    def instance_license_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_license_type", value)

    @property
    @pulumi.getter(name="instanceUsageType")
    def instance_usage_type(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Instance type based on its usage
        """
        return pulumi.get(self, "instance_usage_type")

    @instance_usage_type.setter
    def instance_usage_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_usage_type", value)

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> Optional[pulumi.Input[str]]:
        """
        Details of the current state of the instance lifecycle
        """
        return pulumi.get(self, "lifecycle_details")

    @lifecycle_details.setter
    def lifecycle_details(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lifecycle_details", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        OceInstance Name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="objectStorageNamespace")
    def object_storage_namespace(self) -> Optional[pulumi.Input[str]]:
        """
        Object Storage Namespace of Tenancy
        """
        return pulumi.get(self, "object_storage_namespace")

    @object_storage_namespace.setter
    def object_storage_namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "object_storage_namespace", value)

    @property
    @pulumi.getter
    def service(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        SERVICE data. Example: `{"service": {"IDCS": "value"}}`
        """
        return pulumi.get(self, "service")

    @service.setter
    def service(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "service", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        The current state of the instance lifecycle.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="stateMessage")
    def state_message(self) -> Optional[pulumi.Input[str]]:
        """
        An message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
        """
        return pulumi.get(self, "state_message")

    @state_message.setter
    def state_message(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state_message", value)

    @property
    @pulumi.getter(name="systemTags")
    def system_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"orcl-cloud.free-tier-retained": "true"}`
        """
        return pulumi.get(self, "system_tags")

    @system_tags.setter
    def system_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "system_tags", value)

    @property
    @pulumi.getter(name="tenancyId")
    def tenancy_id(self) -> Optional[pulumi.Input[str]]:
        """
        Tenancy Identifier
        """
        return pulumi.get(self, "tenancy_id")

    @tenancy_id.setter
    def tenancy_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenancy_id", value)

    @property
    @pulumi.getter(name="tenancyName")
    def tenancy_name(self) -> Optional[pulumi.Input[str]]:
        """
        Tenancy Name
        """
        return pulumi.get(self, "tenancy_name")

    @tenancy_name.setter
    def tenancy_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenancy_name", value)

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> Optional[pulumi.Input[str]]:
        """
        The time the the OceInstance was created. An RFC3339 formatted datetime string
        """
        return pulumi.get(self, "time_created")

    @time_created.setter
    def time_created(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_created", value)

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> Optional[pulumi.Input[str]]:
        """
        The time the OceInstance was updated. An RFC3339 formatted datetime string
        """
        return pulumi.get(self, "time_updated")

    @time_updated.setter
    def time_updated(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_updated", value)

    @property
    @pulumi.getter(name="upgradeSchedule")
    def upgrade_schedule(self) -> Optional[pulumi.Input[str]]:
        """
        Upgrade schedule type representing service to be upgraded immediately whenever latest version is released or delay upgrade of the service to previous released version
        """
        return pulumi.get(self, "upgrade_schedule")

    @upgrade_schedule.setter
    def upgrade_schedule(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "upgrade_schedule", value)

    @property
    @pulumi.getter(name="wafPrimaryDomain")
    def waf_primary_domain(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Web Application Firewall(WAF) primary domain


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "waf_primary_domain")

    @waf_primary_domain.setter
    def waf_primary_domain(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "waf_primary_domain", value)


class Instance(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 add_on_features: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 admin_email: Optional[pulumi.Input[str]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 dr_region: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 idcs_access_token: Optional[pulumi.Input[str]] = None,
                 instance_access_type: Optional[pulumi.Input[str]] = None,
                 instance_license_type: Optional[pulumi.Input[str]] = None,
                 instance_usage_type: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 object_storage_namespace: Optional[pulumi.Input[str]] = None,
                 tenancy_id: Optional[pulumi.Input[str]] = None,
                 tenancy_name: Optional[pulumi.Input[str]] = None,
                 upgrade_schedule: Optional[pulumi.Input[str]] = None,
                 waf_primary_domain: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource provides the Oce Instance resource in Oracle Cloud Infrastructure Content and Experience service.

        Creates a new OceInstance.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_oce_instance = oci.oce.Instance("testOceInstance",
            admin_email=var["oce_instance_admin_email"],
            compartment_id=var["compartment_id"],
            idcs_access_token=var["oce_instance_idcs_access_token"],
            object_storage_namespace=var["oce_instance_object_storage_namespace"],
            tenancy_id=oci_identity_tenancy["test_tenancy"]["id"],
            tenancy_name=oci_identity_tenancy["test_tenancy"]["name"],
            add_on_features=var["oce_instance_add_on_features"],
            defined_tags={
                "foo-namespace.bar-key": "value",
            },
            description=var["oce_instance_description"],
            dr_region=var["oce_instance_dr_region"],
            freeform_tags={
                "bar-key": "value",
            },
            instance_access_type=var["oce_instance_instance_access_type"],
            instance_license_type=var["oce_instance_instance_license_type"],
            instance_usage_type=var["oce_instance_instance_usage_type"],
            upgrade_schedule=var["oce_instance_upgrade_schedule"],
            waf_primary_domain=var["oce_instance_waf_primary_domain"])
        ```

        ## Import

        OceInstances can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Oce/instance:Instance test_oce_instance "id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] add_on_features: (Updatable) a list of add-on features for the ocm instance
        :param pulumi.Input[str] admin_email: Admin Email for Notification
        :param pulumi.Input[str] compartment_id: (Updatable) Compartment Identifier
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"foo-namespace.bar-key": "value"}`
        :param pulumi.Input[str] description: (Updatable) OceInstance description
        :param pulumi.Input[str] dr_region: (Updatable) disaster recovery paired ragion name
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        :param pulumi.Input[str] idcs_access_token: Identity Cloud Service access token identifying a stripe and service administrator user
        :param pulumi.Input[str] instance_access_type: Flag indicating whether the instance access is private or public
        :param pulumi.Input[str] instance_license_type: (Updatable) Flag indicating whether the instance license is new cloud or bring your own license
        :param pulumi.Input[str] instance_usage_type: (Updatable) Instance type based on its usage
        :param pulumi.Input[str] name: OceInstance Name
        :param pulumi.Input[str] object_storage_namespace: Object Storage Namespace of Tenancy
        :param pulumi.Input[str] tenancy_id: Tenancy Identifier
        :param pulumi.Input[str] tenancy_name: Tenancy Name
        :param pulumi.Input[str] upgrade_schedule: Upgrade schedule type representing service to be upgraded immediately whenever latest version is released or delay upgrade of the service to previous released version
        :param pulumi.Input[str] waf_primary_domain: (Updatable) Web Application Firewall(WAF) primary domain
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InstanceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Oce Instance resource in Oracle Cloud Infrastructure Content and Experience service.

        Creates a new OceInstance.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_oce_instance = oci.oce.Instance("testOceInstance",
            admin_email=var["oce_instance_admin_email"],
            compartment_id=var["compartment_id"],
            idcs_access_token=var["oce_instance_idcs_access_token"],
            object_storage_namespace=var["oce_instance_object_storage_namespace"],
            tenancy_id=oci_identity_tenancy["test_tenancy"]["id"],
            tenancy_name=oci_identity_tenancy["test_tenancy"]["name"],
            add_on_features=var["oce_instance_add_on_features"],
            defined_tags={
                "foo-namespace.bar-key": "value",
            },
            description=var["oce_instance_description"],
            dr_region=var["oce_instance_dr_region"],
            freeform_tags={
                "bar-key": "value",
            },
            instance_access_type=var["oce_instance_instance_access_type"],
            instance_license_type=var["oce_instance_instance_license_type"],
            instance_usage_type=var["oce_instance_instance_usage_type"],
            upgrade_schedule=var["oce_instance_upgrade_schedule"],
            waf_primary_domain=var["oce_instance_waf_primary_domain"])
        ```

        ## Import

        OceInstances can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Oce/instance:Instance test_oce_instance "id"
        ```

        :param str resource_name: The name of the resource.
        :param InstanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InstanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 add_on_features: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 admin_email: Optional[pulumi.Input[str]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 dr_region: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 idcs_access_token: Optional[pulumi.Input[str]] = None,
                 instance_access_type: Optional[pulumi.Input[str]] = None,
                 instance_license_type: Optional[pulumi.Input[str]] = None,
                 instance_usage_type: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 object_storage_namespace: Optional[pulumi.Input[str]] = None,
                 tenancy_id: Optional[pulumi.Input[str]] = None,
                 tenancy_name: Optional[pulumi.Input[str]] = None,
                 upgrade_schedule: Optional[pulumi.Input[str]] = None,
                 waf_primary_domain: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InstanceArgs.__new__(InstanceArgs)

            __props__.__dict__["add_on_features"] = add_on_features
            if admin_email is None and not opts.urn:
                raise TypeError("Missing required property 'admin_email'")
            __props__.__dict__["admin_email"] = admin_email
            if compartment_id is None and not opts.urn:
                raise TypeError("Missing required property 'compartment_id'")
            __props__.__dict__["compartment_id"] = compartment_id
            __props__.__dict__["defined_tags"] = defined_tags
            __props__.__dict__["description"] = description
            __props__.__dict__["dr_region"] = dr_region
            __props__.__dict__["freeform_tags"] = freeform_tags
            if idcs_access_token is None and not opts.urn:
                raise TypeError("Missing required property 'idcs_access_token'")
            __props__.__dict__["idcs_access_token"] = None if idcs_access_token is None else pulumi.Output.secret(idcs_access_token)
            __props__.__dict__["instance_access_type"] = instance_access_type
            __props__.__dict__["instance_license_type"] = instance_license_type
            __props__.__dict__["instance_usage_type"] = instance_usage_type
            __props__.__dict__["name"] = name
            if object_storage_namespace is None and not opts.urn:
                raise TypeError("Missing required property 'object_storage_namespace'")
            __props__.__dict__["object_storage_namespace"] = object_storage_namespace
            if tenancy_id is None and not opts.urn:
                raise TypeError("Missing required property 'tenancy_id'")
            __props__.__dict__["tenancy_id"] = tenancy_id
            if tenancy_name is None and not opts.urn:
                raise TypeError("Missing required property 'tenancy_name'")
            __props__.__dict__["tenancy_name"] = tenancy_name
            __props__.__dict__["upgrade_schedule"] = upgrade_schedule
            __props__.__dict__["waf_primary_domain"] = waf_primary_domain
            __props__.__dict__["guid"] = None
            __props__.__dict__["idcs_tenancy"] = None
            __props__.__dict__["lifecycle_details"] = None
            __props__.__dict__["service"] = None
            __props__.__dict__["state"] = None
            __props__.__dict__["state_message"] = None
            __props__.__dict__["system_tags"] = None
            __props__.__dict__["time_created"] = None
            __props__.__dict__["time_updated"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["idcsAccessToken"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Instance, __self__).__init__(
            'oci:Oce/instance:Instance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            add_on_features: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            admin_email: Optional[pulumi.Input[str]] = None,
            compartment_id: Optional[pulumi.Input[str]] = None,
            defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            description: Optional[pulumi.Input[str]] = None,
            dr_region: Optional[pulumi.Input[str]] = None,
            freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            guid: Optional[pulumi.Input[str]] = None,
            idcs_access_token: Optional[pulumi.Input[str]] = None,
            idcs_tenancy: Optional[pulumi.Input[str]] = None,
            instance_access_type: Optional[pulumi.Input[str]] = None,
            instance_license_type: Optional[pulumi.Input[str]] = None,
            instance_usage_type: Optional[pulumi.Input[str]] = None,
            lifecycle_details: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            object_storage_namespace: Optional[pulumi.Input[str]] = None,
            service: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            state: Optional[pulumi.Input[str]] = None,
            state_message: Optional[pulumi.Input[str]] = None,
            system_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            tenancy_id: Optional[pulumi.Input[str]] = None,
            tenancy_name: Optional[pulumi.Input[str]] = None,
            time_created: Optional[pulumi.Input[str]] = None,
            time_updated: Optional[pulumi.Input[str]] = None,
            upgrade_schedule: Optional[pulumi.Input[str]] = None,
            waf_primary_domain: Optional[pulumi.Input[str]] = None) -> 'Instance':
        """
        Get an existing Instance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] add_on_features: (Updatable) a list of add-on features for the ocm instance
        :param pulumi.Input[str] admin_email: Admin Email for Notification
        :param pulumi.Input[str] compartment_id: (Updatable) Compartment Identifier
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"foo-namespace.bar-key": "value"}`
        :param pulumi.Input[str] description: (Updatable) OceInstance description
        :param pulumi.Input[str] dr_region: (Updatable) disaster recovery paired ragion name
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        :param pulumi.Input[str] guid: Unique GUID identifier that is immutable on creation
        :param pulumi.Input[str] idcs_access_token: Identity Cloud Service access token identifying a stripe and service administrator user
        :param pulumi.Input[str] idcs_tenancy: IDCS Tenancy Identifier
        :param pulumi.Input[str] instance_access_type: Flag indicating whether the instance access is private or public
        :param pulumi.Input[str] instance_license_type: (Updatable) Flag indicating whether the instance license is new cloud or bring your own license
        :param pulumi.Input[str] instance_usage_type: (Updatable) Instance type based on its usage
        :param pulumi.Input[str] lifecycle_details: Details of the current state of the instance lifecycle
        :param pulumi.Input[str] name: OceInstance Name
        :param pulumi.Input[str] object_storage_namespace: Object Storage Namespace of Tenancy
        :param pulumi.Input[Mapping[str, Any]] service: SERVICE data. Example: `{"service": {"IDCS": "value"}}`
        :param pulumi.Input[str] state: The current state of the instance lifecycle.
        :param pulumi.Input[str] state_message: An message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
        :param pulumi.Input[Mapping[str, Any]] system_tags: Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"orcl-cloud.free-tier-retained": "true"}`
        :param pulumi.Input[str] tenancy_id: Tenancy Identifier
        :param pulumi.Input[str] tenancy_name: Tenancy Name
        :param pulumi.Input[str] time_created: The time the the OceInstance was created. An RFC3339 formatted datetime string
        :param pulumi.Input[str] time_updated: The time the OceInstance was updated. An RFC3339 formatted datetime string
        :param pulumi.Input[str] upgrade_schedule: Upgrade schedule type representing service to be upgraded immediately whenever latest version is released or delay upgrade of the service to previous released version
        :param pulumi.Input[str] waf_primary_domain: (Updatable) Web Application Firewall(WAF) primary domain
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InstanceState.__new__(_InstanceState)

        __props__.__dict__["add_on_features"] = add_on_features
        __props__.__dict__["admin_email"] = admin_email
        __props__.__dict__["compartment_id"] = compartment_id
        __props__.__dict__["defined_tags"] = defined_tags
        __props__.__dict__["description"] = description
        __props__.__dict__["dr_region"] = dr_region
        __props__.__dict__["freeform_tags"] = freeform_tags
        __props__.__dict__["guid"] = guid
        __props__.__dict__["idcs_access_token"] = idcs_access_token
        __props__.__dict__["idcs_tenancy"] = idcs_tenancy
        __props__.__dict__["instance_access_type"] = instance_access_type
        __props__.__dict__["instance_license_type"] = instance_license_type
        __props__.__dict__["instance_usage_type"] = instance_usage_type
        __props__.__dict__["lifecycle_details"] = lifecycle_details
        __props__.__dict__["name"] = name
        __props__.__dict__["object_storage_namespace"] = object_storage_namespace
        __props__.__dict__["service"] = service
        __props__.__dict__["state"] = state
        __props__.__dict__["state_message"] = state_message
        __props__.__dict__["system_tags"] = system_tags
        __props__.__dict__["tenancy_id"] = tenancy_id
        __props__.__dict__["tenancy_name"] = tenancy_name
        __props__.__dict__["time_created"] = time_created
        __props__.__dict__["time_updated"] = time_updated
        __props__.__dict__["upgrade_schedule"] = upgrade_schedule
        __props__.__dict__["waf_primary_domain"] = waf_primary_domain
        return Instance(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="addOnFeatures")
    def add_on_features(self) -> pulumi.Output[Sequence[str]]:
        """
        (Updatable) a list of add-on features for the ocm instance
        """
        return pulumi.get(self, "add_on_features")

    @property
    @pulumi.getter(name="adminEmail")
    def admin_email(self) -> pulumi.Output[str]:
        """
        Admin Email for Notification
        """
        return pulumi.get(self, "admin_email")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Output[str]:
        """
        (Updatable) Compartment Identifier
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        (Updatable) OceInstance description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="drRegion")
    def dr_region(self) -> pulumi.Output[str]:
        """
        (Updatable) disaster recovery paired ragion name
        """
        return pulumi.get(self, "dr_region")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter
    def guid(self) -> pulumi.Output[str]:
        """
        Unique GUID identifier that is immutable on creation
        """
        return pulumi.get(self, "guid")

    @property
    @pulumi.getter(name="idcsAccessToken")
    def idcs_access_token(self) -> pulumi.Output[str]:
        """
        Identity Cloud Service access token identifying a stripe and service administrator user
        """
        return pulumi.get(self, "idcs_access_token")

    @property
    @pulumi.getter(name="idcsTenancy")
    def idcs_tenancy(self) -> pulumi.Output[str]:
        """
        IDCS Tenancy Identifier
        """
        return pulumi.get(self, "idcs_tenancy")

    @property
    @pulumi.getter(name="instanceAccessType")
    def instance_access_type(self) -> pulumi.Output[str]:
        """
        Flag indicating whether the instance access is private or public
        """
        return pulumi.get(self, "instance_access_type")

    @property
    @pulumi.getter(name="instanceLicenseType")
    def instance_license_type(self) -> pulumi.Output[str]:
        """
        (Updatable) Flag indicating whether the instance license is new cloud or bring your own license
        """
        return pulumi.get(self, "instance_license_type")

    @property
    @pulumi.getter(name="instanceUsageType")
    def instance_usage_type(self) -> pulumi.Output[str]:
        """
        (Updatable) Instance type based on its usage
        """
        return pulumi.get(self, "instance_usage_type")

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> pulumi.Output[str]:
        """
        Details of the current state of the instance lifecycle
        """
        return pulumi.get(self, "lifecycle_details")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        OceInstance Name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="objectStorageNamespace")
    def object_storage_namespace(self) -> pulumi.Output[str]:
        """
        Object Storage Namespace of Tenancy
        """
        return pulumi.get(self, "object_storage_namespace")

    @property
    @pulumi.getter
    def service(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        SERVICE data. Example: `{"service": {"IDCS": "value"}}`
        """
        return pulumi.get(self, "service")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        """
        The current state of the instance lifecycle.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="stateMessage")
    def state_message(self) -> pulumi.Output[str]:
        """
        An message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
        """
        return pulumi.get(self, "state_message")

    @property
    @pulumi.getter(name="systemTags")
    def system_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"orcl-cloud.free-tier-retained": "true"}`
        """
        return pulumi.get(self, "system_tags")

    @property
    @pulumi.getter(name="tenancyId")
    def tenancy_id(self) -> pulumi.Output[str]:
        """
        Tenancy Identifier
        """
        return pulumi.get(self, "tenancy_id")

    @property
    @pulumi.getter(name="tenancyName")
    def tenancy_name(self) -> pulumi.Output[str]:
        """
        Tenancy Name
        """
        return pulumi.get(self, "tenancy_name")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> pulumi.Output[str]:
        """
        The time the the OceInstance was created. An RFC3339 formatted datetime string
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> pulumi.Output[str]:
        """
        The time the OceInstance was updated. An RFC3339 formatted datetime string
        """
        return pulumi.get(self, "time_updated")

    @property
    @pulumi.getter(name="upgradeSchedule")
    def upgrade_schedule(self) -> pulumi.Output[str]:
        """
        Upgrade schedule type representing service to be upgraded immediately whenever latest version is released or delay upgrade of the service to previous released version
        """
        return pulumi.get(self, "upgrade_schedule")

    @property
    @pulumi.getter(name="wafPrimaryDomain")
    def waf_primary_domain(self) -> pulumi.Output[str]:
        """
        (Updatable) Web Application Firewall(WAF) primary domain


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "waf_primary_domain")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetFastConnectProviderServiceResult',
    'AwaitableGetFastConnectProviderServiceResult',
    'get_fast_connect_provider_service',
    'get_fast_connect_provider_service_output',
]

@pulumi.output_type
class GetFastConnectProviderServiceResult:
    """
    A collection of values returned by getFastConnectProviderService.
    """
    def __init__(__self__, bandwith_shape_management=None, customer_asn_management=None, description=None, id=None, private_peering_bgp_management=None, provider_name=None, provider_service_id=None, provider_service_key_management=None, provider_service_name=None, public_peering_bgp_management=None, required_total_cross_connects=None, supported_virtual_circuit_types=None, type=None):
        if bandwith_shape_management and not isinstance(bandwith_shape_management, str):
            raise TypeError("Expected argument 'bandwith_shape_management' to be a str")
        pulumi.set(__self__, "bandwith_shape_management", bandwith_shape_management)
        if customer_asn_management and not isinstance(customer_asn_management, str):
            raise TypeError("Expected argument 'customer_asn_management' to be a str")
        pulumi.set(__self__, "customer_asn_management", customer_asn_management)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if private_peering_bgp_management and not isinstance(private_peering_bgp_management, str):
            raise TypeError("Expected argument 'private_peering_bgp_management' to be a str")
        pulumi.set(__self__, "private_peering_bgp_management", private_peering_bgp_management)
        if provider_name and not isinstance(provider_name, str):
            raise TypeError("Expected argument 'provider_name' to be a str")
        pulumi.set(__self__, "provider_name", provider_name)
        if provider_service_id and not isinstance(provider_service_id, str):
            raise TypeError("Expected argument 'provider_service_id' to be a str")
        pulumi.set(__self__, "provider_service_id", provider_service_id)
        if provider_service_key_management and not isinstance(provider_service_key_management, str):
            raise TypeError("Expected argument 'provider_service_key_management' to be a str")
        pulumi.set(__self__, "provider_service_key_management", provider_service_key_management)
        if provider_service_name and not isinstance(provider_service_name, str):
            raise TypeError("Expected argument 'provider_service_name' to be a str")
        pulumi.set(__self__, "provider_service_name", provider_service_name)
        if public_peering_bgp_management and not isinstance(public_peering_bgp_management, str):
            raise TypeError("Expected argument 'public_peering_bgp_management' to be a str")
        pulumi.set(__self__, "public_peering_bgp_management", public_peering_bgp_management)
        if required_total_cross_connects and not isinstance(required_total_cross_connects, int):
            raise TypeError("Expected argument 'required_total_cross_connects' to be a int")
        pulumi.set(__self__, "required_total_cross_connects", required_total_cross_connects)
        if supported_virtual_circuit_types and not isinstance(supported_virtual_circuit_types, list):
            raise TypeError("Expected argument 'supported_virtual_circuit_types' to be a list")
        pulumi.set(__self__, "supported_virtual_circuit_types", supported_virtual_circuit_types)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="bandwithShapeManagement")
    def bandwith_shape_management(self) -> str:
        """
        Who is responsible for managing the virtual circuit bandwidth.
        """
        return pulumi.get(self, "bandwith_shape_management")

    @property
    @pulumi.getter(name="customerAsnManagement")
    def customer_asn_management(self) -> str:
        """
        Who is responsible for managing the ASN information for the network at the other end of the connection from Oracle.
        """
        return pulumi.get(self, "customer_asn_management")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The location of the provider's website or portal. This portal is where you can get information about the provider service, create a virtual circuit connection from the provider to Oracle Cloud Infrastructure, and retrieve your provider service key for that virtual circuit connection.  Example: `https://example.com`
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="privatePeeringBgpManagement")
    def private_peering_bgp_management(self) -> str:
        """
        Who is responsible for managing the private peering BGP information.
        """
        return pulumi.get(self, "private_peering_bgp_management")

    @property
    @pulumi.getter(name="providerName")
    def provider_name(self) -> str:
        """
        The name of the provider.
        """
        return pulumi.get(self, "provider_name")

    @property
    @pulumi.getter(name="providerServiceId")
    def provider_service_id(self) -> str:
        return pulumi.get(self, "provider_service_id")

    @property
    @pulumi.getter(name="providerServiceKeyManagement")
    def provider_service_key_management(self) -> str:
        """
        Who is responsible for managing the provider service key.
        """
        return pulumi.get(self, "provider_service_key_management")

    @property
    @pulumi.getter(name="providerServiceName")
    def provider_service_name(self) -> str:
        """
        The name of the service offered by the provider.
        """
        return pulumi.get(self, "provider_service_name")

    @property
    @pulumi.getter(name="publicPeeringBgpManagement")
    def public_peering_bgp_management(self) -> str:
        """
        Who is responsible for managing the public peering BGP information.
        """
        return pulumi.get(self, "public_peering_bgp_management")

    @property
    @pulumi.getter(name="requiredTotalCrossConnects")
    def required_total_cross_connects(self) -> int:
        """
        Total number of cross-connect or cross-connect groups required for the virtual circuit.
        """
        return pulumi.get(self, "required_total_cross_connects")

    @property
    @pulumi.getter(name="supportedVirtualCircuitTypes")
    def supported_virtual_circuit_types(self) -> Sequence[str]:
        """
        An array of virtual circuit types supported by this service.
        """
        return pulumi.get(self, "supported_virtual_circuit_types")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        Provider service type.
        """
        return pulumi.get(self, "type")


class AwaitableGetFastConnectProviderServiceResult(GetFastConnectProviderServiceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFastConnectProviderServiceResult(
            bandwith_shape_management=self.bandwith_shape_management,
            customer_asn_management=self.customer_asn_management,
            description=self.description,
            id=self.id,
            private_peering_bgp_management=self.private_peering_bgp_management,
            provider_name=self.provider_name,
            provider_service_id=self.provider_service_id,
            provider_service_key_management=self.provider_service_key_management,
            provider_service_name=self.provider_service_name,
            public_peering_bgp_management=self.public_peering_bgp_management,
            required_total_cross_connects=self.required_total_cross_connects,
            supported_virtual_circuit_types=self.supported_virtual_circuit_types,
            type=self.type)


def get_fast_connect_provider_service(provider_service_id: Optional[str] = None,
                                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFastConnectProviderServiceResult:
    """
    This data source provides details about a specific Fast Connect Provider Service resource in Oracle Cloud Infrastructure Core service.

    Gets the specified provider service.
    For more information, see [FastConnect Overview](https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/fastconnect.htm).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_fast_connect_provider_service = oci.Core.get_fast_connect_provider_service(provider_service_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str provider_service_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the provider service.
    """
    __args__ = dict()
    __args__['providerServiceId'] = provider_service_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Core/getFastConnectProviderService:getFastConnectProviderService', __args__, opts=opts, typ=GetFastConnectProviderServiceResult).value

    return AwaitableGetFastConnectProviderServiceResult(
        bandwith_shape_management=__ret__.bandwith_shape_management,
        customer_asn_management=__ret__.customer_asn_management,
        description=__ret__.description,
        id=__ret__.id,
        private_peering_bgp_management=__ret__.private_peering_bgp_management,
        provider_name=__ret__.provider_name,
        provider_service_id=__ret__.provider_service_id,
        provider_service_key_management=__ret__.provider_service_key_management,
        provider_service_name=__ret__.provider_service_name,
        public_peering_bgp_management=__ret__.public_peering_bgp_management,
        required_total_cross_connects=__ret__.required_total_cross_connects,
        supported_virtual_circuit_types=__ret__.supported_virtual_circuit_types,
        type=__ret__.type)


@_utilities.lift_output_func(get_fast_connect_provider_service)
def get_fast_connect_provider_service_output(provider_service_id: Optional[pulumi.Input[str]] = None,
                                             opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetFastConnectProviderServiceResult]:
    """
    This data source provides details about a specific Fast Connect Provider Service resource in Oracle Cloud Infrastructure Core service.

    Gets the specified provider service.
    For more information, see [FastConnect Overview](https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/fastconnect.htm).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_fast_connect_provider_service = oci.Core.get_fast_connect_provider_service(provider_service_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str provider_service_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the provider service.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetExternalDbSystemResult',
    'AwaitableGetExternalDbSystemResult',
    'get_external_db_system',
    'get_external_db_system_output',
]

@pulumi.output_type
class GetExternalDbSystemResult:
    """
    A collection of values returned by getExternalDbSystem.
    """
    def __init__(__self__, compartment_id=None, database_management_configs=None, db_system_discovery_id=None, discovery_agent_id=None, display_name=None, external_db_system_id=None, home_directory=None, id=None, is_cluster=None, lifecycle_details=None, state=None, time_created=None, time_updated=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if database_management_configs and not isinstance(database_management_configs, list):
            raise TypeError("Expected argument 'database_management_configs' to be a list")
        pulumi.set(__self__, "database_management_configs", database_management_configs)
        if db_system_discovery_id and not isinstance(db_system_discovery_id, str):
            raise TypeError("Expected argument 'db_system_discovery_id' to be a str")
        pulumi.set(__self__, "db_system_discovery_id", db_system_discovery_id)
        if discovery_agent_id and not isinstance(discovery_agent_id, str):
            raise TypeError("Expected argument 'discovery_agent_id' to be a str")
        pulumi.set(__self__, "discovery_agent_id", discovery_agent_id)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if external_db_system_id and not isinstance(external_db_system_id, str):
            raise TypeError("Expected argument 'external_db_system_id' to be a str")
        pulumi.set(__self__, "external_db_system_id", external_db_system_id)
        if home_directory and not isinstance(home_directory, str):
            raise TypeError("Expected argument 'home_directory' to be a str")
        pulumi.set(__self__, "home_directory", home_directory)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_cluster and not isinstance(is_cluster, bool):
            raise TypeError("Expected argument 'is_cluster' to be a bool")
        pulumi.set(__self__, "is_cluster", is_cluster)
        if lifecycle_details and not isinstance(lifecycle_details, str):
            raise TypeError("Expected argument 'lifecycle_details' to be a str")
        pulumi.set(__self__, "lifecycle_details", lifecycle_details)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)
        if time_updated and not isinstance(time_updated, str):
            raise TypeError("Expected argument 'time_updated' to be a str")
        pulumi.set(__self__, "time_updated", time_updated)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="databaseManagementConfigs")
    def database_management_configs(self) -> Sequence['outputs.GetExternalDbSystemDatabaseManagementConfigResult']:
        """
        The details required to enable Database Management for an external DB system.
        """
        return pulumi.get(self, "database_management_configs")

    @property
    @pulumi.getter(name="dbSystemDiscoveryId")
    def db_system_discovery_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DB system discovery.
        """
        return pulumi.get(self, "db_system_discovery_id")

    @property
    @pulumi.getter(name="discoveryAgentId")
    def discovery_agent_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the management agent used during the discovery of the DB system.
        """
        return pulumi.get(self, "discovery_agent_id")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        The user-friendly name for the DB system. The name does not have to be unique.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="externalDbSystemId")
    def external_db_system_id(self) -> str:
        return pulumi.get(self, "external_db_system_id")

    @property
    @pulumi.getter(name="homeDirectory")
    def home_directory(self) -> str:
        """
        The Oracle Grid home directory in case of cluster-based DB system and Oracle home directory in case of single instance-based DB system.
        """
        return pulumi.get(self, "home_directory")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the external DB system.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isCluster")
    def is_cluster(self) -> bool:
        """
        Indicates whether the DB system is a cluster DB system or not.
        """
        return pulumi.get(self, "is_cluster")

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> str:
        """
        Additional information about the current lifecycle state.
        """
        return pulumi.get(self, "lifecycle_details")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The current lifecycle state of the external DB system resource.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The date and time the external DB system was created.
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> str:
        """
        The date and time the external DB system was last updated.
        """
        return pulumi.get(self, "time_updated")


class AwaitableGetExternalDbSystemResult(GetExternalDbSystemResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetExternalDbSystemResult(
            compartment_id=self.compartment_id,
            database_management_configs=self.database_management_configs,
            db_system_discovery_id=self.db_system_discovery_id,
            discovery_agent_id=self.discovery_agent_id,
            display_name=self.display_name,
            external_db_system_id=self.external_db_system_id,
            home_directory=self.home_directory,
            id=self.id,
            is_cluster=self.is_cluster,
            lifecycle_details=self.lifecycle_details,
            state=self.state,
            time_created=self.time_created,
            time_updated=self.time_updated)


def get_external_db_system(external_db_system_id: Optional[str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetExternalDbSystemResult:
    """
    This data source provides details about a specific External Db System resource in Oracle Cloud Infrastructure Database Management service.

    Gets the details for the external DB system specified by `externalDbSystemId`.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_external_db_system = oci.DatabaseManagement.get_external_db_system(external_db_system_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str external_db_system_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the external DB system.
    """
    __args__ = dict()
    __args__['externalDbSystemId'] = external_db_system_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:DatabaseManagement/getExternalDbSystem:getExternalDbSystem', __args__, opts=opts, typ=GetExternalDbSystemResult).value

    return AwaitableGetExternalDbSystemResult(
        compartment_id=__ret__.compartment_id,
        database_management_configs=__ret__.database_management_configs,
        db_system_discovery_id=__ret__.db_system_discovery_id,
        discovery_agent_id=__ret__.discovery_agent_id,
        display_name=__ret__.display_name,
        external_db_system_id=__ret__.external_db_system_id,
        home_directory=__ret__.home_directory,
        id=__ret__.id,
        is_cluster=__ret__.is_cluster,
        lifecycle_details=__ret__.lifecycle_details,
        state=__ret__.state,
        time_created=__ret__.time_created,
        time_updated=__ret__.time_updated)


@_utilities.lift_output_func(get_external_db_system)
def get_external_db_system_output(external_db_system_id: Optional[pulumi.Input[str]] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetExternalDbSystemResult]:
    """
    This data source provides details about a specific External Db System resource in Oracle Cloud Infrastructure Database Management service.

    Gets the details for the external DB system specified by `externalDbSystemId`.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_external_db_system = oci.DatabaseManagement.get_external_db_system(external_db_system_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str external_db_system_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the external DB system.
    """
    ...
